pub enum ConditionalOrderType {
StopMarket,
StopLimit,
TakeProfitMarket,
TakeProfitLimit,
}Expand description
Conditional order types supported by dYdX.
Variants
StopMarket
Triggers at trigger price, executes as market order.
StopLimit
Triggers at trigger price, places limit order at limit price.
TakeProfitMarket
Triggers at trigger price for profit taking, executes as market order.
TakeProfitLimit
Triggers at trigger price for profit taking, places limit order at limit price.